********************************************************************************
** This do file defines all globals and runs all other do files for Paper 1
********************************************************************************

clear all
version 17.0


** Install external packages (comment out if already installed)
/*
ssc install binscatter, replace
ssc install center, replace 
ssc install egenmore, replace 
ssc install estout, replace
ssc install grstyle, replace
ssc install gtools, replace

* Packages to call R from within Stata
net install github, from("https://haghish.github.io/github/")
github install haghish/rcall, stable
*/

********************************************************************************
**# 0. Define file paths
********************************************************************************

* Change the global "master_folder" to the location of the README file on your computer
global master_folder = "${dropbox}/outside/Networks and Social Mobility/data_release/Austin_In_Progress"

global public_data = "${master_folder}/Other public covariate data"
global fb_data = "${master_folder}/Social Capital Data"


global paper1_code = "${master_folder}/Code/Paper 1"

global paper1_figs = "${master_folder}/Paper 1 Exhibits/Figures"
global paper1_tables = "${master_folder}/Paper 1 Exhibits/Tables"


********************************************************************************
**# 1. Stata graph styles
********************************************************************************

grstyle init

* background color 
grstyle color background white

* graph size
grstyle graphsize y 5
grstyle graphsize x 8

* legend options
grstyle linestyle legend none

* axis options
grstyle color axis_title gs5
grstyle gsize axis_title 3.7
grstyle color axisline gs5
grstyle gsize axis_title_gap tiny
grstyle linewidth axisline medium

* symbols
grstyle symbolsize p medsmall
grstyle linewidth p	medthick

* tick options
grstyle color tick gs5
grstyle color tick_label gs5
grstyle gsize tick_label 3.7
grstyle anglestyle vertical_tick 0
grstyle linewidth tick medium

grstyle color key_label gs5

grstyle margin graph "2 2 5 7"


********************************************************************************
**# 2. Execute do files for Paper 1
********************************************************************************

* Main Tables
do "${paper1_code}/Tables/Main_Table_1.do"
do "${paper1_code}/Tables/Main_Table_2.do"

* Main Figures
* Note: Main Figure 1 cannot be replicated with public data. Use our data exploration tool at https://socialcapital.org to recreate Main Figure 2.
do "${paper1_code}/Figures/Main_Figure_3.do"
do "${paper1_code}/Figures/Main_Figure_4.do"
do "${paper1_code}/Figures/Main_Figure_5.do"
do "${paper1_code}/Figures/Main_Figure_6.do"


* Extended Data Tables
* Note: Extended Data Tables 1 and 4 cannot be replicated with public data 
do "${paper1_code}/Tables/Extended Data_Table_2.do"
do "${paper1_code}/Tables/Extended Data_Table_3.do"

* Extended Data Figures 
* Note: Extended Data Figures 2 and 6 cannot be replicated with public data. Use our data exploration tool at https://socialcapital.org to recreate Extended Data Figure 1.
do "${paper1_code}/Figures/Extended Data_Figure_3.do"
do "${paper1_code}/Figures/Extended Data_Figure_4.do"
do "${paper1_code}/Figures/Extended Data_Figure_5.do"


* Supplementary Tables
* Note: When restricted to the set of social capital measures that we publicly release, Supplementary Table 1 is the same as Main Table 1. Supplementary Table 5 cannot be replicated with public data.
do "${paper1_code}/Tables/Supplementary_Table_2.do"
do "${paper1_code}/Tables/Supplementary_Table_3.do"

* Supplementary Figures
* Note: Supplementary Figures 1; 12; 13; 14; and 15 cannot be replicated with public data. Use our data exploration tool at https://socialcapital.org to recreate Supplementary Figure 5A.
do "${paper1_code}/Figures/Supplementary_Figure_2.do"
do "${paper1_code}/Figures/Supplementary_Figure_3.do"
do "${paper1_code}/Figures/Supplementary_Figure_4.do"
do "${paper1_code}/Figures/Supplementary_Figure_5.do"
do "${paper1_code}/Figures/Supplementary_Figure_6.do"
do "${paper1_code}/Figures/Supplementary_Figure_7.do"
do "${paper1_code}/Figures/Supplementary_Figure_8.do"
do "${paper1_code}/Figures/Supplementary_Figure_9.do"
do "${paper1_code}/Figures/Supplementary_Figure_10.do"
do "${paper1_code}/Figures/Supplementary_Figure_11.do"
do "${paper1_code}/Figures/Supplementary_Figure_16.do"


********************************************************************************
* Remove custom scheme 
grstyle clear, erase

* Remove R tempfiles 
cap erase "${paper1_code}/Rplots.pdf"
cap erase "${paper1_figs}/.Rhistory"
