********************************************************************************
** This master do file defines all globals and runs all other do files for Paper 2
********************************************************************************

clear all
version 17.0


** Install external packages (comment out if already installed)
/*
ssc install binscatter, replace
ssc install center, replace 
ssc install egenmore, replace 
ssc install estout, replace
ssc install gtools, replace

* Packages to call R from within Stata
net install github, from("https://haghish.github.io/github/")
github install haghish/rcall, stable
*/ 


********************************************************************************
**# 0. Define file paths
********************************************************************************

* Change the global "master_folder" to the location of the README file on your computer
global master_folder = "${dropbox}/outside/Networks and Social Mobility/data_release/Austin_In_Progress"

global public_data = "${master_folder}/Other public covariate data"
global fb_data = "${master_folder}/Social Capital Data"


global paper2_code = "${master_folder}/Code/Paper 2"

global paper2_figs = "${master_folder}/Paper 2 Exhibits/Figures"
global paper2_tables = "${master_folder}/Paper 2 Exhibits/Tables"


********************************************************************************
**# 1. Stata graph styles
********************************************************************************

grstyle init

* background color 
grstyle color background white

* graph size
grstyle graphsize y 5
grstyle graphsize x 8

* legend options
grstyle linestyle legend none

* axis options
grstyle color axis_title gs5
grstyle gsize axis_title 3.7
grstyle color axisline gs5
grstyle gsize axis_title_gap tiny
grstyle linewidth axisline medium

* symbols
grstyle symbolsize p medsmall
grstyle linewidth p	medthick

* tick options
grstyle color tick gs5
grstyle color tick_label gs5
grstyle gsize tick_label 3.7
grstyle anglestyle vertical_tick 0
grstyle linewidth tick medium

grstyle color key_label gs5

grstyle margin graph "2 2 5 7"


********************************************************************************
**# 2. Execute do files for Paper 2
********************************************************************************

* Main Tables
do "${paper2_code}/Tables/Main_Table_1.do"

* Main Figures
* Note: Main Figures 1-3 cannot be replicated with public data. Use our data exploration tool at https://socialcapital.org to recreate Main Figure 4.
do "${paper2_code}/Figures/Main_Figure_5.do"


* Extended Data Tables
* Note: ED Tables 1a, 3, and 4 cannot be replicated with public data.
do "${paper2_code}/Tables/Extended Data_Table_1.do"
do "${paper2_code}/Tables/Extended Data_Table_2.do"

* Extended Data Figures
do "${paper2_code}/Figures/Extended Data_Figure_1.do"
do "${paper2_code}/Figures/Extended Data_Figure_2.do"
do "${paper2_code}/Figures/Extended Data_Figure_3.do"


* Supplementary Tables 
* Note: Supplementary Table 3 cannot be replicated with public data 
do "${paper2_code}/Tables/Supplementary_Table_1.do"

* Supplementary Figures 
* Note: Supplementary Figures 1, 4, 5, 6, 7, and 8 cannot be replicated with public data.
do "${paper2_code}/Figures/Supplementary_Figure_2.do"
do "${paper2_code}/Figures/Supplementary_Figure_3.do"

********************************************************************************
* Remove custom scheme 
grstyle clear, erase

* Remove R tempfiles 
cap erase "${paper2_code}/Rplots.pdf"
cap erase "${paper2_figs}/.Rhistory"


